from distutils.core import setup

setup(
		name		=	'mlibs', 
		version		=	'1.4.0',
		py_modules	=	['kl_print'],
                author          =       'szu_lee',
                author_email    =       '664304797@qq.com',
                url             =       'http://www.coollang.com',
                description     =       'Make the world a better place',

	 )
